package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!0````!$``6$````#0``,*<```````T`"``
M"0`H`!X`'0````8````T$```-!```#0```$@```!(`````4````$`````P``
M`500``%4$``!5`````T````-````!`````$````!`````!`````0``````"V
M:```MF@````%``$```````$``+[P$`&^\!`!OO````)L```2L`````8``0``
M`````@``OQ`0`;\0$`&_$````.````#@````!@````0````$```!9!```600
M``%D````1````$0````$````!&1TY5```+8H$`"V*!``MB@````4````%```
M``0````$9'3E40``````````````````````````````!@````1D=.52``"^
M\!`!OO`0`;[P```!$````1`````$`````2]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````#P````0````4`````T=.50`A
MLX[P[:#&97["RUPD&X$^UTG&T0```"4```!0````"`````@$$!``@`1`)0$`
M`*BH`8:B`B`$0"D$*$]',J(X"`R$B@```%````!1````````````````````
M4P```%4```!6````5P```%@```!9`````````%H```!<````70````````!>
M````````````````````7P```&(``````````````&,```!E````9@```&@`
M````````:@```&P``````````````&X```!O````<@````!QLM7)+4?>SDG[
MX*,.[]/J:Z/=I[:;Q2^>X\W;>U_OYX&<^8?60PEK"Y<Z#,8%F$>0!8G%GN(4
M#0[D_R%OBP&R0)RYQ'R:?VN;G*E_']_%;AQ8<=E\DN.[?-1DU,#C2ZWMVV(R
M"@*GX6;,KV9K2O![`<9'XNS514/%CD%]J6'*E"P_Y<(@"R*A'=/;\F!LH?H.
M\8VY`````````````````````````NH``````````!(```````"Q````````
M```2```````#>```````````$@```````V,``````````!(```````&A````
M```````2```````#J```````````$@```````GH``````````!(````````1
M```````````@````````(```````````(````````VD``````````!(`````
M``&-```````````2```````#R0``````````$@```````6X``````````!(`
M``````&````````````2```````$!0``````````$@```````QH`````````
M`!(```````+)```````````2```````"+```````````$@```````/T`````
M`````!(```````(<```````````2```````#C0``````````$@```````<H`
M`````````!(```````0Z```````````2```````#^```````````$@``````
M`M8``````````!(```````+1```````````2```````"F```````````$@``
M`````>H``````````!(```````&F```````````2```````"-0``````````
M$@```````[8``````````!(```````0L```````````2```````!+P``````
M````$@```````\$``````````!(````````T```````````2```````#TP``
M````````$@```````5T``````````!(```````#(```````````2```````$
M#```````````$@```````Z$``````````!(```````/Q```````````2````
M```#A@``````````$@```````UP``````````!(```````3_```````````2
M```````!00``````````$@```````^$``````````!(```````)<````````
M```2```````#0@``````````$@```````OL``````````!(```````).````
M```````2```````#E```````````$@```````I$``````````!(```````&K
M```````````2```````#2P``````````$@```````YL``````````!(`````
M``-_```````````2````````[```````````$@```````$(``````````!(`
M``````/H```````````2```````$)```````````$@```````-<`````````
M`!(```````'^```````````2```````"A0``````````$@```````5``````
M`````!(```````-Q```````````2```````#,0``````````$@```````L(`
M`````````!(```````$=```````````2```````$%@``````````$@``````
M`D,``````````!(```````!4```````````2```````!V```````````$@``
M`````&,``````````!(```````0S```````````2````````CP``````````
M$@```````SD``````````!(```````,L```````````2````````>```````
M````$@```````0L``````````!(```````&W$`!04``````2```````%?1``
M.P````JH$@``#```!:D0`#9@```"1!(```P```26$`!6<``````2```-```$
M3A`!P6`````$(0``&@``!&X0`#%P````#!(```P```4I$`!.D````,`2```,
M```%/A``6C0``%OJ$0``#@```*`0`%(P`````!(```````44$`'!1``````0
M```8```%%A`!P40`````(```&```!3D0`<%4````!!$``!D```1-$`'!8```
M``0A```:```$C!``3U`````$$@``#```!9P0`#&````":!(```P```2R$``X
ML````)`2```,```$3!`!P6`````$$0``&@``!$<0`$N````"M!(```P```3M
M$``Y0````#@2```,```%"!``2D````#8$@``#```!%T0`<%<`````!``__$`
M``1I$`'1H``````0`/_Q```$G!``1;````2,$@``#````PL0`%:X````!!$`
M``X```4:$``6$````"02```,```$P!``,)````#4$@``#```!.$0`#10```"
M"!(```P```)J$`!2(``````2```````$?Q``,_````!8$@``#```!%80`<%<
M`````!``__$```5-$`!+(````%02```,```$UA`"050`````$```&0``!2$0
M`"_0````2!(```P```5I$`'!6`````01```9```"HQ`!P7`````3$0``&@``
M!8H0`#F````!>!(```P```4C$``5P``````2```+`&QI8G!E<FPN<V\N-2XQ
M,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES
M7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R;%])
M97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7TEC
M;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI;F9O
M7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L
M7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`
M4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S=E]S
M971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]):6Y?
M979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P='(`
M4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``
M;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G
M971S<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?
M24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L
M:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P
M<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?
M;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!?4T1!7T)!4T5?`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET
M`%]?;&EB8U]C<W5?:6YI=`!N86UE7VQO861?;7E?<&%R7W!L`%A37TEN=&5R
M;F%L<U]005)?0TQ%05)35$%#2P!S:7IE7VQO861?;7E?<&%R7W!L`'!A<E]M
M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R7VEN
M:71?96YV`$=,24)#7S(N-`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?
M,BXR`$=,24)#7S(N,RXT`$=,24)#7S(N,``````"`````P`#````!```````
M```#````!0```````P`&``<``````````P````,`!``"``(```````,````%
M``,````#````"```````!0`#``,``P`#``,````#`````P`"`````P`#````
M"0`#``,```````,``P````````````,``P`'````"0````````````,````#
M``,``````````0`!``$``P`!``$``0````$``0`!``,``0`!``$``P`!``$`
M`0`!``$``0`!``$``0`!`````0`!``$``0`!``$````!``$``0`&```#`0``
M`!````!P#6EI%`````D```6V````$`UI:1,````(```%P````!`):1ER````
M!@``!<H````0#6EI$@````4```76````$`EI&70````$```%X````!`-:6D0
M`````P``!>P```````$``@```K(````0``````UI:1(````'```%U@```!`-
M:6D0`````@``!>P`````$`&_\```"!0`````$`'!8```8!,`````$`'!<```
M<A,`````$`'``````14`````$`'`!````A4`````$`'`"````Q4`````$`'`
M#```!!4`````$`'`$```!14`````$`'`%```!A4`````$`'`&```!Q4`````
M$`'`'```4!4`````$`'`(```"!4`````$`'`)```"A4`````$`'`*```"Q4`
M````$`'`+```#!4`````$`'`,```#14`````$`'`-```#A4`````$`'`.```
M#Q4`````$`'`/```$!4`````$`'`0```$14`````$`'`1```$A4`````$`'`
M2```$Q4`````$`'`3```%!4`````$`'`4```%14`````$`'`5```%A4`````
M$`'`6```%Q4`````$`'`7```&!4`````$`'`8```&14`````$`'`9```&A4`
M````$`'`:```&Q4`````$`'`;```'!4`````$`'`<```'14`````$`'`=```
M'A4`````$`'`>```'Q4`````$`'`?```(!4`````$`'`@```(14`````$`'`
MA```(A4`````$`'`B```(Q4`````$`'`C```)!4`````$`'`D```:Q4`````
M$`'`E```6!4`````$`'`F```)14`````$`'`G```)A4`````$`'`H```)Q4`
M````$`'`I```*!4`````$`'`J```*14`````$`'`K```*A4`````$`'`L```
M*Q4`````$`'`M```+!4`````$`'`N```+14`````$`'`O```+A4`````$`'`
MP```+Q4`````$`'`Q```,!4`````$`'`R```,14`````$`'`S```,A4`````
M$`'`T```,Q4`````$`'`U```-!4`````$`'`V```-14`````$`'`W```-A4`
M````$`'`X```-Q4`````$`'`Y```.!4`````$`'`Z```.14`````$`'`[```
M.A4`````$`'`\```.Q4`````$`'`]```/!4`````$`'`^```/14`````$`'`
M_```/A4`````$`'!````/Q4`````$`'!!```0!4`````$`'!"```014`````
M$`'!#```0A4`````$`'!$```0Q4`````$`'!%```1!4`````$`'!&```114`
M````$`'!'```1A4`````$`'!(```1Q4`````$`'!)```2!4`````$`'!*```
M214`````$`'!+```2A4`````$`'!,```2Q4`````$`'!-```3!4`````$`'!
M.```314`````$`'!/```3A4`````$`'!0```3Q4`````E"'_\'P(`J:0`0`4
MD\$`"$*?``5_R`*F/]X``CO>JB"`'O_\+X```$&>``A(`#IU2``!(4@`.6V`
M`0`4?`@#IH/!``@X(0`03H``(`````!\*0MX5"$`-C@```"4(?_P?`@#II`!
M```]`!``A:A6J$@`.Q````````````````"4(?_@?`@"II.!`!"3H0`4/X`0
M`I`!`"23P0`8D^$`'(@<P80O@```0)X`9#_@$`(_H!`"/\`0`CN]OO@[WK[\
M?]WP4($_P8A_WA9P.][__W^)\$!`G``P.__!B&`````Y*0`!52`0.I$_``!\
M'0`N?`D#IDZ`!"&!/P``?XGP0$&<_^`X```!F!S!A(`!`"2#@0`0@Z$`%(/!
M`!A\"`.F@^$`'#@A`"!.@``@8````)0A__!\"`*FD`$`%(`!`!0X(0`0?`@#
MIDZ``"!@````/2`0`I0A__!\"`*F.&F_`)`!`!2`";\`+X```$&>`!P](```
M.`D``"^```!!G@`,?`D#IDZ`!"&``0`4."$`$'P(`Z9.@``@8````&````"4
M(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@`````)0A_J`X```0?`D#ICEC
M`!B3@0%0DZ$!5)/!`5B3X0%<.2$`#&````!@````8````(0+``24"0`$0@#_
M^#@``$`Y(0!`?`D#IF````!@````.2D`!(%I_^R`"0``@4G_U'U@`GB!:?_,
M?`!2>'P`6GA4``@^D`D`#$(`_]B!@P`0@^$`$(`#``"`PP`$@.,`"("#``Q_
M[/H4@0$`%(.!`!@__UJ"5,KP/E0%*#Y\BS!X@Z$`''SI,#A]!$(4._]YF7UI
M2WA__RH4?4L`.'SE`'@]"%J"?3]*%'RK6W@Y"'F9?X?B%'T(6A15*R@^?6A:
M%%0>\#X_G%J"52CP/GU%2'A5?R@^?2GP.#N<>9D_O5J"?YSZ%'RI2WA_WUAX
M?65`.#N]>9E]75(4?^4K>(.A`"1_ZBH4@*$`('T\2A15*B@^/[U:@CRE6H)]
M7U(457_P/CEE>9E_R_(4527P/GT+2'A57"@^?2GX.'^>XA1]:4MX?_Y0>'U+
M*#@[O7F9?1U"%'_+6WB#H0`L?\A:%($!`"A]/$H452LH/C^]6H(]"%J"?7Y:
M%%5>\#XY2'F9?^KZ%%4H\#Y\JDAX57PH/GTI\#A_G^(4?4E+>'_?6'A]:D`X
M.[UYF7R]*A1_ZE-X@Z$`-'_E4A2`H0`P?3Q*%%4J*#X_O5J"/*5:@GU?4A15
M?_`^.65YF7_+\A15)?`^?0M(>%5<*#Y]*?@X?Y[B%'UI2WA__E!X?4LH.#N]
M>9E]'4(4?\M;>(.A`#Q_R%H4@0$`.'T\2A15*R@^/[U:@CT(6H)]?EH455[P
M/CE(>9E_ZOH452CP/GRJ2'A5?"@^?2GP.'^?XA1]24MX?]]8>'UJ0#@[O7F9
M?+TJ%'_J4WB#H0!$?^52%("A`$!]/$H452HH/C^]6H(\I5J"?5]2%%5_\#XY
M97F9?\OR%%4E\#Y]"TAX55PH/GTI^#A_GN(4?6E+>'_^4'A]2R@X.[UYF7T=
M0A1_RUMX@Z$`3'_(6A2!`0!(?3Q*%%4K*#X_O5J"/0A:@GU^6A157O`^.4AY
MF7_J^A15*/`^?*I(>%5\*#Y]*?`X?Y_B%'U)2WA_WUAX?6I`.#N]>9E\O2H4
M?^I3>(.A`%1_Y5(4@*$`4'T\2A15*B@^/[U:@CRE6H)]7U(457_P/CEE>9E_
MR_(4527P/GT+2'A57"@^?2GX.'^>XA1]:TMX.[UYF7U\6A1]'4(4@X$`6(.A
M`%Q__E!X?4DH.#^<6H(_O5J".[UYF3N<>9E_R4MX?YSZ%'R_6'A\O2H4@Z$`
M8'T(2A15:2@^?2A*%#^];MI52O`^53XH/CN]ZZ%5:/`^?YSR%'UK4#A]7DAX
M?5U2%(.A`&1__UMX?2M`.#^];MI5*?`^.[WKH7_+6WA]/D)X?1U"%(.A`&A_
M_/H4?*5:%#^];MI7ZR@^?65:%#N]ZZ%7Y?`^?]_Z>'R^2GA]/4H4@Z$`;'_J
M^A15:B@^/[UNVG__4A0[O>NA56KP/G_+6GA]7BIX?+TJ%(.A`'!]"%H45^LH
M/C^];MI]:%H4.[WKH5?H\#Y_W_IX?1Y2>'U=4A2#H0!T?^GZ%%5I*#X_O6[:
M?3]*%#N]ZZ%5?_`^?\M:>'_^0GA]'4(4@Z$`>'RE6A15*R@^/[UNVGUE6A0[
MO>NA527P/G_)2GA\OOIX?_WZ%(.A`'Q]2DH456DH/C^];MI]*DH4.[WKH55J
M\#Y_RUIX?5XJ>'R]*A2#H0"`?0A:%%4K*#X_O6[:?6A:%#N]ZZ%5*/`^?\E*
M>'T>4GA]75(4@Z$`A'__2A15:2@^/[UNVGT_2A0[O>NA57_P/G_+6GA__D)X
M?1U"%(.A`(A\I5H452LH/C^];MI]95H4.[WKH54E\#Y_R4IX?+[Z>'_]^A2#
MH0",?4I*%%5I*#X_O6[:?2I*%#N]ZZ%5:O`^?\M:>'U>*GA\O2H4@Z$`D'T(
M6A15*R@^/[UNVGUH6A0[O>NA52CP/G_)2GA]'E)X?5U2%(.A`)1__TH456DH
M/C^];MI]/TH4.[WKH55_\#Y_RUIX?_Y">'T=0A2#H0"8?*5:%%4K*#X_O6[:
M?65:%#N]ZZ%5)?`^?\E*>'R^^GA__?H4@Z$`G'U*2A15:2@^?2I*%#^];MI5
M:O`^?\M:>'T(6A1]7BIX52LH/CN]ZZ%]:%H4?+TJ%(.A`*!5*/`^?\E*>'__
M2A1]'E)X56DH/C^];MI]/TH457_P/G_+6G@[O>NA?_Y">'RE6A15*R@^?5U2
M%(.A`*1]95H4527P/G_)2GA\OOIX?4I*%%5I*#Y]2DH4/[UNVE5I\#Y_RUIX
M@\$`J#N]ZZ%]'4(4/]YNVG^(6A1]/2IX54LH/CO>ZZ%]?%H4?_[Z%(/!`*Q_
MO5)X54CP/G^_ZA15?R@^?_WZ%#_>;MJ#H0"P56KP/GT<2G@[WNNA?YQ:>'R^
M*A0_O8\<?5Y#>%?K\#Y_A>(4.[V\W%?E*#Y_W_@X?5Y`.'R\*A2#@0"T?__S
M>'^]2A1_O?H45+\H/GU^4WA__?H4@Z$`N#^<CQQ4J?`^.YR\W'_%*#A]?E`X
M?YQ"%'RE\W@_O8\<?3Y;>%?H\#Y_G"H4.[V\W%?E*#Y_W_@X?3Y8.'R\*A2#
M@0"\?__S>'^]4A1_O?H45+\H/GT>2WA__?H4@Z$`P#^<CQQ4JO`^.YR\W'_%
M*#A]'D@X?YQ:%'RE\W@_O8\<?5Y#>%?K\#Y_G"H4.[V\W%?E*#Y_W_@X?5Y`
M.'R\*A2#@0#$?__S>'^]2A1_O?H45+\H/GU^4WA__?H4@Z$`R#^<CQQ4J?`^
M.YR\W'_%*#A]?E`X?YQ"%'RE\W@_O8\<?3Y;>%?H\#Y_G"H4.[V\W%?E*#Y_
MW_@X?3Y8.'R\*A2#@0#,?__S>'^]4A1_O?H45+\H/GT>2WA__?H4@Z$`T#^<
MCQQ4JO`^.YR\W'_%*#A]'D@X?YQ:%'RE\W@_O8\<?5Y#>%?K\#Y_G"H4.[V\
MW%?E*#Y_W_@X?5Y`.'R\*A2#@0#4?__S>'^]2A1_O?H45+\H/GU^4WA__?H4
M@Z$`V#^<CQQ4J?`^.YR\W'_%*#A]?E`X?YQ"%'RE\W@_O8\<?3Y;>%?H\#Y_
MG"H4.[V\W%?E*#Y_W_@X?3Y8.'R\*A2#@0#<?__S>'^]4A1_O?H45+\H/GT>
M2WA__?H4@Z$`X#^<CQQ4JO`^.YR\W'_%*#A]'D@X?YQ:%'RE\W@_O8\<?5Y#
M>%?K\#Y_G"H4.[V\W%?E*#Y_W_@X?5Y`.'R\*A2#@0#D?__S>'^]2A1_O?H4
M5+\H/GU^4WA__?H4@Z$`Z#^<CQQ4J?`^.YR\W'_%*#A]?E`X?YQ"%'RE\W@_
MO8\<?3Y;>%?H\#Y_G"H4.[V\W%?E*#Y_W_@X?3Y8.'R\*A2#@0#L?__S>'^]
M4A1_O?H45+\H/GT>2WA__?H4@Z$`\#^<CQQ4JO`^.YR\W'_%*#A]'D@X?YQ:
M%'RE\W@_O8\<?5Y#>%?K\#Y_G"H4.[V\W%?E*#Y_W_@X?5Y`.'R\*A2#@0#T
M?__S>'^]2A1_O?H45+\H/G_]^A2#H0#X?7Y3>#^<CQQ4J?`^/[V/''_%*#@[
MO;S<?7Y0.#N<O-Q\OO-X?5U2%'^<0A2#H0#\?2A;>%?E\#Y_G/(45_XH/GT?
M^#A]*%@X?]SR%'_H0W@_O8\<?+]+>'^*0A1___`X?*I(.%?(*#X[O;S<?1Q"
M%%?>\#Y]?5H4@Z$!`'_J4WA_WRIX?4M2%%4+*#Y]:EH4/[W*8U4*\#Y_Z$)X
M@^$!!#N]P=9]/4H4/__*8WU=\GA]"4(4.__!UE5I*#Y]*$H4?_\J%("A`0A5
M:/`^?ZM:>'__6A1]'5)X52LH/CRERF-]?UH453_P/G^I2GB#H0$,.*7!UGRE
M\A1__D)X/[W*8WRE2A0[O<'656DH/GU=4A2#H0$0?25*%%5E\#Y_RUIX/[W*
M8WR^^G@[O<'6?4I:%'T=0A2#H0$452LH/GUJ6A15*O`^/[W*8W_)2G@[O<'6
M?5XJ>'_]^A2#H0$8?0A*%%5I*#X_O<IC?2A*%#N]P=95:/`^?+TJ%(.A`1Q_
MRUIX?1Y2>'__6A0_O<IC52LH/CN]P=9]?UH4?5U2%(.A`2!5/_`^?\E*>'_^
M0G@_O<IC?*5*%#N]P=95:2@^?1U"%(.A`21])4H4567P/G_+6G@_O<IC?+[Z
M>#N]P=9]2EH4?_WZ%(.A`2A5*R@^?6I:%%4J\#X_O<IC?\E*>#N]P=9]7BIX
M?+TJ%(.A`2Q]"$H456DH/C^]RF-]*$H4.[W!UE5H\#Y_RUIX?1Y2>'U=4A2#
MH0$P?_]:%%4K*#X_O<IC?7]:%#N]P=95/_`^?\E*>'_^0GA]'4(4@Z$!-'RE
M2A15:2@^/[W*8WTE2A0[O<'6567P/G_+6GA\OOIX?_WZ%(.A`3A]2EH452LH
M/C^]RF-]:EH4.[W!UE4J\#Y_R4IX?5XJ>'R]*A2#H0$\?0A*%%5I*#X_O<IC
M?2A*%#N]P=95:/`^?\M:>'T>4GA__UH4?5U2%(.A`4!5*R@^?7]:%%4_\#Y_
MR4IX/[W*8W_^0GA\I4H456DH/CN]P=9])4H4567P/G_+6GA]'4(4@Z$!1'R^
M^GA]2EH452LH/C^]RF-]:EH452KP/G_)2GA]7BIX?0A*%%5I*#Y]"$H4.[W!
MUE5I\#Y_RUIX@\$!2'_]^A2#H0%,?3Q2>#_>RF-__UH4?Z#J%%4+*#X[WL'6
M?7]:%'_>*A15'_`^/+W*8W^(0GA_WD(456`H/G_H2G@XI<'6?!X"%'U%4A1]
M"%IX56OP/GT*0A14"B@^?)\B%'U(4A1\`#(4?.LZ%)%#``"0@P`,?2EB%(.!
M`5"#H0%4D`,`!)#C``B#P0%8@^$!7#@A`6"1(P`03H``()0A_]!\"`*FDX$`
M()-A`!Q\?!MY.&```)-!`!B0`0`T?)HC>).A`"23P0`HD^$`+$""`#"``0`T
M@T$`&(-A`!R#@0`@?`@#IH.A`"2#P0`H@^$`+#@A`#!.@``@8````#T@$`*#
M:<%@+YL``$&>_\B('```.\```"^```!!G@`H+X``/4&>`"!_GN-XC!X``2^`
M```O```]09X`"$":__!_W/!0@_L``#A@```OGP``09[_A']]VWA@````8```
M`'_C^WA_A.-X?\7S>$@`+84O@P``0)X`$'P?\*XO@``]09X`((?]``0OGP``
M0)[_U#A@``!+__]`8````&````!_N^A0.'X``7^]%G"3N@``?'\:%$O__R!@
M````8````)0A_^!\"`*FD`$`)#B!`!Q,QC&"2__^S8`!`"0X(0`@?`@#IDZ`
M`"!@````8````)0A_]!\"`*FD^$`+)/!`"A\?QMX/\`0`G_C^WB0`0`T.($`
M'$S&,8)+__Z)+X,``$&>`$A@````8````&````"!(0`<@![!8%4I$#I]($H4
MA`D`!)`)__PO@```0)[_]'_C^W@X@0`<3,8Q@DO__D4O@P``0)[_S(`!`#2#
MP0`H@^$`+#@A`#!\"`.F3H``()0A_^`X8```?`@"II/A`!R0`0`D2``LO8!C
M``!(`"FE2``H,8$C```X8```@^D`!$@`+*&`8P``2``IB4@`*,5\:1MX.&``
M`(@)``"8'P`82``L@8!C``!(`"EI2``G]8$C```X8```@^D`!$@`+&6`8P``
M2``I34@`*)F!(P``.&```(`)`!!4`$W^L!\`&D@`+$&`8P``2``I*4@`)[6!
M(P``.&```(/I``1(`"PE@&,``$@`*0T\@!``.*```#B$6-A(`"N-D'\`'#A@
M``!(`"P!@&,``$@`*.E(`"=U@2,``#A@``"#Z0`$2``KY8!C``!(`"C-2``G
MZ8`#```X8```D!\`($@`*\F`8P``2``HL4@`)SV!(P``.&```(/I``1(`"NM
M@&,``$@`*)5(`"JQ.````($C```OB0``09X`(#A@``!(`"N)@&,``$@`*'%(
M`"J-@2,``(`)`&R0'P`D.&```#O@``!(`"ME@&,``$@`*$U(`";9@2,``#A@
M``"!*0`$D^D`*$@`*T6`8P``2``H+4@`)KF!(P``.&```($I``23Z0`L2``K
M)8!C``!(`"@-2``FF8$C```X8```@^D`!$@`*PF`8P``2``G\4@`*KV``P``
MD!\`,(`!`"2#X0`<."$`('P(`Z9.@``@8````&````!@````E"'_8'P(`J:3
MX0"<D\$`F'Q_&WF0`0"DDV$`C).!`)"3H0"408(`$(@?```O@```0)X`,(`!
M`*2#80",@X$`D(.A`)1\"`.F@\$`F(/A`)PX(0"@3H``(&````!@````2``G
M\7Q^&WE!@O_,/X`0`#N<5T!@````8````&````!_P_-X2``H/7QI&WE_X_MX
M.VD`$T&"`)R("0`3+X``+D&>`-!(`"A-?'T;>']CVWA(`"A!?'T:%#AC``)(
M`"C5?X;C>'_G^WA_:-MX.(```7Q]&W@XH/__3,8Q@D@`*<5_I.MX.*$`&#A@
M``-(`"8%+X/__W^CZWA!G@`4@`$`*%0`!"8O@$``09X`F$@`)_5_H^MX2``F
M[7_#\WA(`">E?&D;>7_C^W@[:0`30(+_;'_#\WA(`"@=?^/[>$@`*(6``0"D
M@V$`C(.!`)"#H0"4?`@#IH/!`)B#X0"<."$`H$Z``"!@````8````&````"(
M"0`4+X```$&>_P@O@``N0)[_)(@)`!4O@```09[^]$O__Q1@````8````&``
M``!+__YA2___;&````!@````E"'_X'P(`J:3X0`<D\$`&'Q_&W@X8```D`$`
M)#O```!(`"D!@&,``$@`)>E(`"@5?^3[>'QE&W@X8``#2``F-2^#``!!G@`L
M@`$`)(/A`!Q_P_-X@\$`&#@A`"!\"`.F3H``(&````!@````8````$@`*+&`
M8P``2``EF4@`)\6``P`05``$)B^`0`!!G@`L.&```$@`*(V`8P``2``E=4@`
M)Z&!(P`052D$)FT@__\O@*``0)[_E'_C^W@X@``"2``EP8`!`"2#X0`<?`@#
MIGQ^`#17WME^?\/S>(/!`!@X(0`@3H``(&````!@````E"'_P'P(`J:3@0`P
MDZ$`-'Q]&WB3P0`XD^$`/)`!`$23`0`@DR$`))-!`"B380`LB`0``&@>`#TC
MW@``?\0!E'_#\WA(`"8-.($`''Q\&WA_H^MX3,8Q@DO_^2E\?QMY08(`<$@`
M)>T[____.3[__W^<&$!!G0'P8````&````","0`!G!\``2^```!`GO_T?`,#
M>(`!`$2#`0`@@R$`)(-!`"A\"`.F@V$`+(.!`#"#H0`T@\$`.(/A`#PX(0!`
M3H``(&````!@````8````#]@$`(X@``(.^```(,;P6"`&```+X```$&>`"!_
M"<-XA`D`!#O_``$O@```0)[_]#B?``)4A!`Z/2`0`H`)P8PO@```09X!''\#
MPWA7^1`Z2``C$3@`__\O@P``?'H;>)![P6!!GO]<.!\``3D@``!4`!`Z?3H!
M+I/A`!R('0``?ZGK>"^```!!G@`L+X``/4">`!1(```@8````&````!!F@`4
MC`D``2^````O```]0)[_\'T]2%`X?``"@_O!8'QC2A1(`"5=.`#__R^#``!\
M?\DN09[^[#T@$`*('0``+X```(%IP6"!(0`<52D0.GTK2"Z8"0``09X`,"^`
M`#U`G@`42```)&````!@````09H`&(P=``&<"0`!+X```"\``#U`GO_L.```
M/3O>__^8"0``8````&````!@````C!X``9P)``$O@```0)[_]$O__G!@````
M8````&`````X```!?(,C>)`)P8Q(`"2U.`#__WQZ&WE!@OY(5_D0.G\$PWA_
M)<MX2``E&9-;P6!+__[8@R$`'#]@$`)7.1`Z2__^W&````!@````8````)0A
M[]`XH`__?`@"II.A$"23P1`H?'X;>#Q@$`"3X1`LD`$0-'R=(W@X8U=(.($`
M'(`"C_B0`1`<.````$@`)*5\?QMY0($`G#@!$"!](/H4B`GO^R^```!!G@!X
M.&$`'#B``"]_Y?MX2``DV2^#``!!G@!P.&```$@`)3F`8P``2``B(7_$\W@X
MH0`<?^;[>$@`(W&``1`<@2*/^'P`2GDY(```0((`7(`!$#2#H1`D@\$0*(/A
M$"PX(1`P?`@#IDZ``"!@````8````&`````W____0(+_B&````!@````.&``
M`$@`),V`8P``2``AM7_$\WA_I>MX2``A>4O__YA(`".18````&````!@````
ME"'_\#A@``!\"`*FD`$`%$@`))&`8P``2``A>3R`$``\H!``/,`0`#B$5U@X
MI5(@.,97=$@`)$V``0`4."$`$'P(`Z9.@``@8````&````"4(?_P.&```'P(
M`J:0`0`42``D08!C``!(`"$I2___E3A@``!(`"0M@&,``$@`(14\P!``/(`0
M`#C&6-@\H!``.(17@#BE1;!\QS-X.0```$@`(=&``0`4."$`$'P(`Z9.@``@
M8````&````!@````E"'?T'P(`J:3X2`LD\$@*#O@``"0`2`T@`*/^)`!(!PX
M````2``?33S`$``]`!``?&<;>#B```$X81`8.*`0`3C&5Y@Y"%>D3,8Q@D@`
M(V4O@P``0)P`/($A(!R``H_X?2D">3@```!_X_MX0((`9(`!(#2#P2`H@^$@
M+#@A(#!\"`.F3H``(&````!@````.&$0&#B!`!0XH!``2``B=7Q^&WE!@/^T
M.'X``4@`(?5\?QMY08+_I#B!`!1_Q?-X2``A(3@```!\'_&N2___C$@`(?%@
M````8````&````"4(?_P."$`$$O__QA@````?8``)I0A[[!\"`*FDZ$01)/!
M$$A\?AMX/&`0`)/A$$R0`1!4.&-7K'R?(WB1@1`DDL$0*)+A$"R3`1`PDR$0
M-)-!$#B381`\DX$00(`"C_B0`1`<.````$S&,8)+__4%.(``+WQ]&WA_P_-X
M2``>U2^#``!!G@!P/&`0`'_$\W@X8U>X3,8Q@DO_^CF!(1`<@`*/^'TI`GDX
M````?\/S>$""`<2``1!4@8$0)(+!$"B"X1`L?`@#IH,!$#"#(1`T?8"!((-!
M$#B#81`\@X$00(.A$$2#P1!(@^$03#@A$%!.@``@?\/S>#^`$`!(`"`E.YQ7
MR'^$XWA\>QMX?^/[>$@`(/%\=AMY08+_<#\@$``_0!``.N```"X=```_`!``
M.WL``3LY5\P[6E?48O>``#O@``!@````8````&````"(%@``+X```$">``@Z
MV%>H09(`&'^CZWA^Q+-X2``AM2^#``!!G@"P?L.S>$@`'Z5]-AH4B`G__R^`
M`"]`G@`8G^G__SAC__^("?__+X``+T&>__!\>QH4+X,/_T&=_MPX@``!.*`0
M`'\FRWA^Q[-X?TC3>'_)\W@X80`<3,8Q@D@`(0$X8```2``A*8!C``!(`!X1
M2``@/3B!`!Q\91MX.&```T@`'2TO@P``0)X`)$@`(0&`8P``2``=Z4@`(!6`
M`P`05``$)G^`N`!!G@`@.&```'^$XWA(`!_9+X,``'QV&WA`GO\<2__^4#AA
M`!PX@``!2``>'2^#``!`GO_4/&`0`#B!`!PX8U>X3,8Q@DO_^'$X80`<2``@
MV7Q^&WA+__XL2``?;6````!@````E"'_\'QK&WB(`P``+X```$&>`#PY(P`!
M2```&&````"("0``.2D``2^```!!G@`@+X``+T">_^R("0``?2M+>#DI``$O
M@```0)[_Z'UC6W@X(0`03H``(&````!@````E"'_X'P(`J:3P0`8D^$`''Q^
M&WF0`0`D08(`N(@>```O@```09X`K$@`'ADX`___?+X"%'^>*$!`G`!,?!X`
MKB^``"]`G@#,?'X:%'P>*%`X8__^?YX80'P)`Z9`O0`@2``!G&````!@````
M8````(@%```O@``O0)X`F#BE__]"`/_P?X7P`$">`,2(!0``+X``+T&>`2P\
M8!``.&-7U$@`'\%\?QMX@`$`)(/!`!A_X_MX@^$`'#@A`"!\"`.F3H``(&``
M``!@````8````#A@``)(`!X-?'\;>4&"_\PX`"X`?^/[>+`?``"``0`D@\$`
M&(/A`!PX(0`@?`@#IDZ``"!@````8````&`````X!?__?YX`0'P>*%!\"0.F
M09T`T"^>__]`O@`42```Q(@%```O@``O09[_3#BE__]"`/_P?X7P`$&>_T0X
M!?__?YX`0'P>*%!\"0.F09T`B"^>__]!G@"`8````&`````XI?__0D``$(@%
M```O@``O09[_\'R^*%`[X```.`4``BN`$`!!G?\4/^`0`G_$\W@[_\&,.*4`
M`3O_``0XP!``?^/[>$@`&BU+__[P8````#A@``([X```2``=&2P#``!!@O[8
M.``N`'Q_&WBP`P``2__^R#@```%\"0.F2___A#@```%\"0.F2___1#@```%\
M"0.F2__^>&````!@````E"'_L#R`$`!\"`*F.(16O#B@`"*3@0!`DZ$`1#^@
M$``_@!``D\$`2)/A`$P_X!``.[U7K)`!`%0[_U@`/\`0`#O>6!P[G%@H.&$`
M&(`"C_B0`0`\.````$@`&[D\8!``.&-7V$S&,8)+__!)/&`0`#AC5^1,QC&"
M2__P.3Q@$``X8U?L3,8Q@DO_\"D\8!``.&-7^$S&,8)+__`9?^/[>$S&,8)+
M__`-/&`0`#AC6!!,QC&"2__O_7^CZWA,QC&"2__O\7_#\WA,QC&"2__OY7^#
MXWA,QC&"2__OV3Q@$``X8U@T3,8Q@DO_[\D\8!``.&-7N$S&,8)+_^^Y/&`0
M`#AC6$!,QC&"2__OJ3Q@$``X8UA,3,8Q@DO_[YD\8!``.&-86$S&,8)+_^]9
M?&0;>4&"`!!_@^-X3,8Q@DO_]*4\8!``.&-8;$S&,8)+_^\U?&0;>4&"`!0\
M8!``.&-8@$S&,8)+__1]/&`0`#AC6(Q,QC&"2__O#7QD&WE!@@!D?Z/K>$S&
M,8)+__19/(`0`'_C^W@XA%B\3,8Q@DO_]$6!(0`\@`*/^'TI`GDX````0((`
MD(`!`%2#@0!`@Z$`1(/!`$A\"`.F@^$`3#@A`%!.@``@8````&````!@````
M/&`0`#AC6)Q,QC&"2__NE7QD&WE!@@`<?\/S>$S&,8)+__/A2___B&````!@
M````/(`0`#AA`"DXA%BP.*``"D@`&Y$O@P``0)[_9'_#\W@X@0`S3,8Q@DO_
M\ZE+__]02``:L6````!@````8````)0A_^!\"`*FD^$`')`!`"0_X!`"@!_!
M4"^`__]!G@`D?`,#>(`!`"2#X0`<."$`('P(`Z9.@``@8````&`````\8!``
M.&-8'$S&,8)+_^WE.````"P#``!!@@`<B2,``"^)``!!G@`0:2``,'P``-!4
M``_^D!_!4'P#`WB``0`D@^$`'#@A`"!\"`.F3H``()0A__!\"`*FD`$`%$@`
M&85(`!EA.````"P#``!!@@`(@`,``'P#`WB``0`4."$`$'P(`Z9.@``@8```
M`&`````](!``E"'_L#DI5KQ\"`*FD^$`3)/!`$B0`0!4DZ$`1'Q]&WB#Z0`D
M@`D`.),A`#2300`X@.D`*($)`"R380`\DX$`0(%)`#"!:0`TD^$`&)#A`!R1
M`0`@D4$`))%A`"B0`0`LB!\``"^```!!G@"$/V`0`#^`$``[P0`8.WM7S#N<
M5\A(```H8````&````!(`!D1+X,``$&>`(B'_@`$B!\``"^```!!G@!(?^/[
M>$S&,8)+_^RM?Z3K>'QY&WE!@@`0B!D``"^```!`GO_$?^/[>'^DZWA,QC&"
M2__QY8?^``2('P``+X```$">_\"``0!4@R$`-(-!`#B#80`\?`@#IH.!`$"#
MH0!$@\$`2(/A`$PX(0!03H``(&````!_H^MX2``7[7QZ&WA_(\MX2``7X7QZ
M&A0X8P`"2``8=3B```$XH/__?V;;>'^GZWA\>AMX?XCC>'\IRWA,QC&"2``9
M87_C^WA_1--X3,8Q@DO_\5%+__\H8````&`````\`/__?"P+>&``?M`](!``
M?"$!;GP(`J8Y*5:\@,D`3(#I`%"!"0!4@4D`6(%I`%R`B0!D@*D`:)`,``23
M+/_D/R`0`)-L_^R3C/_P.SE7K).L__23S/_XD^S__)(L_\1\?QMX/&$``9),
M_\B2;/_,DHS_T)*L_]22S/_8DNS_W),,_^"33/_H@`D`8(/)`$B#B0!`@ZD`
M1(-I`#R!*0!L@B*/^)(C@.PZ(```DV$`,'\CRWB3P0`\DX$`-).A`#B0@0!`
MD*$`1)$A`$B0P0`8D.$`')$!`""100`DD6$`*)`!`"Q,QC&"2__J^7Q^&WE!
M@@`0B!X``"^```!`G@@T2__]07Q[&WE!@@A8B]L``"^>``!!G@!`2``5^7]I
MVW@Y0`!?8````&````!@````@6,``%?>"#Q\"_(N<!,(`$""``B920``C\D`
M`2^>``!`GO_@@&$`&(@#```O@```09X&X#O```%(```T8````#M```!7R1`Z
M8UJ`\#O>``%_6@H4?3I*%#TI__^`:7\HB`,``"^```!!G@:H3,8Q@DO_ZD%\
M?1MY08+_R$O_[J4O@P``09[_O'^CZWA(`!?U?'H;>4&"_ZQ_0]-X/X`0`$@`
M%<$[G%?4?'T;>']CVWA(`!6Q?[T:%#N]!`1_H^MX2``607Q^&WA_H^MX2``6
M-3S`$``](!``.*#__SC&6,A_1]-X?XCC>#DI6-1_:MMX?'T;>#B```%,QC&"
M2``7%3B``>U_H^MX2``2V3Q@$`!_V/-X.&-:&$S&,8)+_^F5+X,``$&>!OR#
M?P``2``757QD&WA_8]MX2__T&7Q[&WE!@@;@?V/;>$@`%1DO@P`#?'H;>$"=
M`#PX8__\/(`0`'Q[&A0XA%C<2``6^2^#``!`G@`@+YH`!$&>!CA_6](4B!K_
M^R^``"]!G@8H8````$O_^O$O@P``09X!6#R`$``\8!``.(18O#AC6!Q,QC&"
M2__N83]@$``_0!``2``2%3M[6-@\P!``.(```3B@__]\:1MX.,99!'_#\WA_
MI^MX?XCC>']JVWA,QC&"2``6)3O@```[6ED42```3&````!(`!&Q@`,``"^`
M`!%`G@!,2``1P3O_``$X@``!DV$`"#B@__]_1M-X?&D;>'^GZWA_P_-X?XCC
M>'_J^WA,QC&"2``5T7_#\W@X@`'M2``1E2^#__]!GO^L?Z/K>$@`$Q5_(\MX
M?\3S>$S&,8)+_^VE?\/S>$O_^MT\80`!@,.`[(!BC_A\QAIY.&```'\#PWA`
M@@;D@6$``(`+``2"*__$@DO_R()K_\Q\"`.F@HO_T(*K_]2"R__8@NO_W(,+
M_^"#*__D@TO_Z(-K_^R#B__P@ZO_](/+__B#Z__\?6%;>$Z``"!@````8```
M`&````!_8]MX.(```$S&,8)(`!3U?'\;>4&"_I@XH/__.,#_[CC@``)(`!&=
M?^/[>#B!`$PXH``&2``2'8@!`$PO@```0)X`$(@!`$TO@`!#09X%L'_C^W@X
MH```.,```#C@``!(`!%A/&$``3T@9T5A*2,!.````)$C@$R0`X!@/2#OS6$I
MJXF0`X!DD`.`J)$C@%`]()BZ82G<_I$C@%0](!`R82E4=I$C@%@](,/282GA
M\)$C@%Q@````8````&`````XH```?^/[>#B!`$Q@I8``2``1@7QZ&WE`@0%<
M/,$``5=`&#B!)H!@?`!*%'^)`$!!G000@2:`9#U!``%72Q]^?2E:%'];TW@Z
MP0!,@&J`J)`*@&"1*H!D+X,``$&>`'0@`P!`?U;3>'^:``!`G0`(?!8#>#E@
M```^(0`!86N`:#B!`$Q]:PH4?L6S>'QK&A1(`!(!@!&`J'P6`A0O@`!`D!&`
MJ$">_UPX8```.D$`3&!C@$Q_=M!0?&,*%'[2LA1+_];A8````&````!@````
M+YL`/T"=`&!_=]MX?MJS>#A@``!_1--X8&.`:#B@`$!\8PH4.O?_P$@`$9DX
M8```.UH`0&!C@$Q\8PH42__6E2^7`#]!G?_,.WO_P%=IT;XX"0`!52DP,E0`
M,#)^U@(4?VG84#A@```^80`!8&.`:'[$LWA_9=MX.,``1'QC"A1(`!`ADW.`
MJ#B@``!_X_MX.($`3&"E@`!(`!`I?'H;>4&!_JP_00`!?^/[>$@`$:4X````
M8`"`\(/Z@&"#>H!D?``*%%?I[KY]8$H4.`D``2^``#@Y(/^`F2O_>$&=`T@X
MX```.(```&#G@&@@H``X?.<*%'QG`A1(``]Y/B$``5=G1CY7:(0^5VK"/E?K
M1CY7Z80^5^#"/ICQ@*"9$8"A/D$``3A@``"948"BFW&`HV!C@$R9<8"DF3&`
MI7QC"A28$8"FF_&`ISXA``%+_]6%@1*`3(%R@%2!4H!0@3*`6(`2@%Q5$H0^
M57K"/II1@-F;48#B.D```%4[1CY5/X0^50=&/E43PCY55$8^556$/E5,PCY5
M=D8^57>$/E4CPCY4!$8^5`6$/E0&PCYB4H#8/T`0`)D1@-N:<8#:FW&`Y)OQ
M@.5_89(4.^```)CQ@-B:D8#<.UI8_)JQ@-V9D8#>F5&`WYK1@.":\8#AF7&`
MXYAQ@.:9,8#GF)&`Z)BQ@.F8T8#JF!&`ZT@```Q@````C/L``3I@```X@``!
M8G.`K#B@__]^<PH4?T;3>'QS^A1,QC&"2``172^?`"8[_P`"0)[_T#]!``$X
M````.2```#S`$`!A*8"L/4`0`)@:@-1_P_-X.(```3B@__\XQECL?Z?K>'^(
MXWA]*0H4.4I8V$S&,8)(`!$-2__[4&````"#P0`P.Z```8@>```O@```0)X`
M/$@``(1@````8````#@```!7J1`Z8`"`\#N]``%\``H4?2!*%#TI__^#R7]`
MB!X``"^```!!G@!0?\/S>$O_Y\$O@P``09[_R'_#\WA(`!$1?'H;>4""^2`X
M````5ZD0.F``@/`[O0`!?``*%'T@2A0]*?__@\E_0(@>```O@```0)[_N#M`
M``!+__CL@_\`!"^?``!!GOG8?^/[>$@`#J$K@P`#0)WYR#AC__P\@!``?'\:
M%#B$6.1(`!"%+X,``$">^:Q_^_MX2__YI#T!``&!*(!D.2D``4O_^^Q+__51
M?\/S>$@`$'E\>!MX2__Z:&````!@````8````(-_``!+__D@8````&````"`
M80!`B`,``"^```!!G@!<.\```6````!@````8````$S&,8)+_^)=+X,``$&>
M`!!(`!`A?'L;>4""]W0Z0```5\D0.F)2@/`[W@`!?E(*%'TR2A0]*?__@&E_
M4(@#```O@```0)[_O#]@$``[>UC`2__WA#C````@H`!`8,:`:#B```!\Q@H4
M?&8"%$@`##4X8```8&.`3'QC"A1+_]*%.&```#B```!@8X!H.*``.'QC"A1(
M``P-2__\E(@!`$XO@`!!0)[Z3(@!`$\O@`!#0)[Z0(@!`%`O@`!(0)[Z-(@!
M`%$O@`!%0)[Z*#C`_\8XX``".*#__W_C^WA(``N%.($`3'_C^W@XH``I2``,
M!3S`$``]0!``?\/S>#B```$XH/__.,98['^GZWA_B.-X.2$`3#E*6-A,QC&"
M2``.I4O_^.A(``VM8````&````"4(?_0.&```'P(`J:300`8DV$`')`!`#23
M@0`@DZ$`))/!`"B3X0`L2``.F8!C``!(``N!2``+_3@```&8`P``/&`0`#AC
M6`!,QC&"2__@Y2P#``!!@@`0B`,``"^``#%!G@*`2__P33A@``!(``Y5@&,`
M`$@`"ST\@!``.*```3B$62@XP``+2``*V2P#``!!@@*0/Z`0`H%C``P[P```
M.[W!C($]$`2#:P`8+XD``4"=`+0[X``!2```,&````"`B0`,?X/C>$@`#ADO
M@P``0)X`D($]$`0[_P`!.]X``7^)^`!`G0"`.&```$@`#=6`8P``2``*O7]D
MVWA_Q?-X.,```$@`#"U\>AMY08(`5($Z``"!71`(5^L0.H`)``A_BE@N<`L$
M`$""_Y@X8```2``-D8!C``!(``IY@)H``#B@```XP``"2``-Z7QD&WA_@^-X
M2``-C2^#``!!GO]X@3T0!#@)__]_@/``09X!Y#A@``!(``U-@&,``$@`"C4\
M@!``.*```3B$63`XP``%2``)T7Q_&WE!@@`\.&```$@`#2&`8P``2``*"8$_
M``P\H!``.*59-(")``!(``G%@3\`#($I``"`"0`(=`D`0$""`6`X8```2``,
MZ8!C``!(``G1/(`0`#B@``$XA%D\.,``!4@`"6U\?QMY08(`/#Q@$``X8U>X
M3,8Q@DO_WR5\?AMY08(!?#A@``!(``RE@&,``$@`"8V!/P`,?\7S>(")``!(
M``E-.&```$@`#(6`8P``2``);4@`">DX````?&D;>#A@``"8"0``2``,98!C
M``!(``E-2``,B3@```"0`P``/&`0`#AC5ZQ,QC&"2__>L2^#``"0?1`,09X!
M1#B``>U(``?-?&8;>4&"`!0OA@`109X`#"^&__]`G@$(@`$`-(-!`!B#80`<
M@X$`('P(`Z:#H0`D@\$`*(/A`"PX(0`P3H``(&````!@````B`,``2^```!`
MGOU\.&```$@`"]&`8P``2``(N3R`$``XH``!.(19*#C```M(``A5+`,``$""
M_8!@````8````#^@$`([O<&,2__^2&`````X8```2``+C8!C``!(``AU@3\`
M#(")``!(``I)2__^B"^)``%`G?X<.^```6`````X8```._\``4@`"UF`8P``
M2``(07]DVWA(``?9@!T0!'^`^`!!G?_<2__]Z&````!(``LQ@&,``$@`"!F!
M?P`,@3T0"(!K``"`B0``2__E94O__HB!/1`(@+T0##Q@$``X8UEP@(D``$S&
M,8)(``I%@'T0"$O_\7V!/P`,D'T0#($I``"`"0`(<`L$`$&"`$R`:0`,@)T0
M"$@`"-F!/P`,@7T0"'Q^&WB!*0``@ZL``(`)``AP"P0`08(`2("I``P\8!``
M?Z3K>#AC64!_QO-X3,8Q@D@`"=TX8```2``*A8!C``!(``=M@3\`##B@```X
MP``"@(D``$@`"ME+__^8.&```$@`"EV`8P``2``'18$_``PXH```.,```H")
M``!(``JQ?&4;>$O__YA@````E"'_X'P(`J:3P0`8D^$`''Q^&WB0`0`D2__I
M^8@#``!\?QMX+X```$&>`$1\:1MX2```(&````!@````8````#DI``&("0``
M+X```$&>`"`O@``O0)[_[#DI``%]/TMXB`D``"^```!`GO_H2__N!2^#``!!
MG@`P+YX``$&>`"B('@``+X```$&>`!P\@!``?^/[>#B$6-1(``A)?Y\8`$&>
M`!R``0`D@\$`&(/A`!PX(0`@?`@#IDZ``""``0`D@^$`''_#\WB#P0`8."$`
M('P(`Z9+_]Z,8````&````"4(?_P.&```'P(`J:0`0`42``)08!C``!(``8I
M.(#__T@`!G$X8```2``)*8!C``!(``81/(`0`#B@```XA">@2``)<8`!`!0X
M(0`0?`@#IDZ``"!@````8````&````"4(?_0?`@"II!A`!R0@0`8D*$`%)`!
M`#23X0`LD\$`*#AA`!PX@0`8.*$`%$@`"+4\@!``/&`0`#B$4%`X8U(P?(4C
M>$@``GTX8```2``%Q8OC```OGP``0)X`-$@`!:4](!`"+X,``)!IT9Q!G@)`
M2``&83A@``!(``AY@&,``$@`!6%(``?-F^,``#A@``!(``AA@&,``$@`!4E(
M``AE?&D;>#A@``"("0``8````I@)``!(``@]@&,``$@`!25(``A!/2`0`,`)
M5RP](!``B`,``&````&8`P``/`!#,)`!``B`80`<.&,`!9!A``S)H0`(_:T`
M*,@)5S`](!``_:T`*L@)5SC_C0``09T!B#_@$`)48Q`Z.__!C$@`!T6!00`8
M@*$`'#T`$``OA0`!?&D;>)!_$`@Y8P`,@`H``)`#```X"%G`/0`0`)`#``0X
M"%HT/0`0`)`#``@X"%G$D`,`##@```20'Q`$0)T`(#@%__]\"0.F8````&``
M``"$"@`$E`L`!$(`__@XI0`#.6```(!_$!!4H!`Z/(`0`'TF2W@XA#`@..``
M`'UI`2Y(``,1?'X;>4&"`%B`?Q`02``%T3Q@$``X8U@03,8Q@DO_V9$O@P``
M09X`9(!_$!!(``+!2``$G8`!`#2#X0`L?\/S>(/!`"@X(0`P?`@#IDZ``"!@
M````8````&````"`?Q`02``#77Q^&WB`?Q`02``%<3Q@$``X8U@03,8Q@DO_
MV3$O@P``0)[_I(!_$`PO@P``09X`,$O__'F`?Q`02``"44@`!"V``0`T@^$`
M+'_#\WB#P0`H."$`,'P(`Z9.@``@/&`0`#AC5ZQ,QC&"2__8X2^#``"0?Q`,
M09[_4$O__[@\8!``/(`0`CAC6/@XA,%P3,8Q@D@`!9DX8``!2``&D0``````
M`````````'P(`J9"GP`%E"'_\#C```"3P0`(D`$`%'_(`J8_W@`".][PO($^
M@``OB0``09X`"(#)``!(``)=@`$`%(/!``@X(0`0?`@#IDZ``"``````E"'_
MT'P(`J9"GP`%D\$`*).A`"23(0`4DT$`&'RY*WA\FB-XDV$`').!`"!\>QMX
MD`$`-)/A`"Q_R`*F/]X``CO>\&Q+_\;M@[Z`!(.>@`!_G>!0?YP6<4&"`#P[
MO?_\.^```&````!@````8````(0=``1_8]MX?T33>'\ERW@[_P`!?`D#IDZ`
M!"%_G^!`09S_X(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#P0`H@^$`
M+#@A`#!.@``@3H``(````````````````)0A__!\"`*FD`$`%)/A``P_X!`"
M._^^](`?__PO@/__09X`)#O___Q@````8````'P)`Z9.@`0AA!___"^`__]`
MGO_P@`$`%(/A``PX(0`0?`@#IDZ``"!@````8````)0A__!\"`*FD`$`%(`!
M`!0X(0`0?`@#IDZ``"``````/6`0`H%KP`!]:0.F3H`$(#U@$`*!:\`$?6D#
MIDZ`!"`]8!`"@6O`"'UI`Z9.@`0@/6`0`H%KP`Q]:0.F3H`$(#U@$`*!:\`0
M?6D#IDZ`!"`]8!`"@6O`%'UI`Z9.@`0@/6`0`H%KP!A]:0.F3H`$(#U@$`*!
M:\`<?6D#IDZ`!"`]8!`"@6O`('UI`Z9.@`0@/6`0`H%KP"1]:0.F3H`$(#U@
M$`*!:\`H?6D#IDZ`!"`]8!`"@6O`+'UI`Z9.@`0@/6`0`H%KP#!]:0.F3H`$
M(#U@$`*!:\`T?6D#IDZ`!"`]8!`"@6O`.'UI`Z9.@`0@/6`0`H%KP#Q]:0.F
M3H`$(#U@$`*!:\!`?6D#IDZ`!"`]8!`"@6O`1'UI`Z9.@`0@/6`0`H%KP$A]
M:0.F3H`$(#U@$`*!:\!,?6D#IDZ`!"`]8!`"@6O`4'UI`Z9.@`0@/6`0`H%K
MP%1]:0.F3H`$(#U@$`*!:\!8?6D#IDZ`!"`]8!`"@6O`7'UI`Z9.@`0@/6`0
M`H%KP&!]:0.F3H`$(#U@$`*!:\!D?6D#IDZ`!"`]8!`"@6O`:'UI`Z9.@`0@
M/6`0`H%KP&Q]:0.F3H`$(#U@$`*!:\!P?6D#IDZ`!"`]8!`"@6O`='UI`Z9.
M@`0@/6`0`H%KP'A]:0.F3H`$(#U@$`*!:\!\?6D#IDZ`!"`]8!`"@6O`@'UI
M`Z9.@`0@/6`0`H%KP(1]:0.F3H`$(#U@$`*!:\"(?6D#IDZ`!"`]8!`"@6O`
MC'UI`Z9.@`0@/6`0`H%KP)!]:0.F3H`$(#U@$`*!:\"4?6D#IDZ`!"`]8!`"
M@6O`F'UI`Z9.@`0@/6`0`H%KP)Q]:0.F3H`$(#U@$`*!:\"@?6D#IDZ`!"`]
M8!`"@6O`I'UI`Z9.@`0@/6`0`H%KP*A]:0.F3H`$(#U@$`*!:\"L?6D#IDZ`
M!"`]8!`"@6O`L'UI`Z9.@`0@/6`0`H%KP+1]:0.F3H`$(#U@$`*!:\"X?6D#
MIDZ`!"`]8!`"@6O`O'UI`Z9.@`0@/6`0`H%KP,!]:0.F3H`$(#U@$`*!:\#$
M?6D#IDZ`!"`]8!`"@6O`R'UI`Z9.@`0@/6`0`H%KP,Q]:0.F3H`$(#U@$`*!
M:\#0?6D#IDZ`!"`]8!`"@6O`U'UI`Z9.@`0@/6`0`H%KP-A]:0.F3H`$(#U@
M$`*!:\#<?6D#IDZ`!"`]8!`"@6O`X'UI`Z9.@`0@/6`0`H%KP.1]:0.F3H`$
M(#U@$`*!:\#H?6D#IDZ`!"`]8!`"@6O`['UI`Z9.@`0@/6`0`H%KP/!]:0.F
M3H`$(#U@$`*!:\#T?6D#IDZ`!"`]8!`"@6O`^'UI`Z9.@`0@/6`0`H%KP/Q]
M:0.F3H`$(#U@$`*!:\$`?6D#IDZ`!"`]8!`"@6O!!'UI`Z9.@`0@/6`0`H%K
MP0A]:0.F3H`$(#U@$`*!:\$,?6D#IDZ`!"`]8!`"@6O!$'UI`Z9.@`0@/6`0
M`H%KP11]:0.F3H`$(#U@$`*!:\$8?6D#IDZ`!"`]8!`"@6O!''UI`Z9.@`0@
M/6`0`H%KP2!]:0.F3H`$(#U@$`*!:\$D?6D#IDZ`!"`]8!`"@6O!*'UI`Z9.
M@`0@/6`0`H%KP2Q]:0.F3H`$(#U@$`*!:\$P?6D#IDZ`!"`]8!`"@6O!-'UI
M`Z9.@`0@/6`0`H%KP3A]:0.F3H`$(#U@$`*!:\$\?6D#IDZ`!"`]8!`"@6O!
M0'UI`Z9.@`0@2``!0$@``3Q(``$X2``!-$@``3!(``$L2``!*$@``21(``$@
M2``!'$@``1A(``$42``!$$@``0Q(``$(2``!!$@``0!(``#\2```^$@``/1(
M``#P2```[$@``.A(``#D2```X$@``-Q(``#82```U$@``-!(``#,2```R$@`
M`,1(``#`2```O$@``+A(``"T2```L$@``*Q(``"H2```I$@``*!(``"<2```
MF$@``)1(``"02```C$@``(A(``"$2```@$@``'Q(``!X2```=$@``'!(``!L
M2```:$@``&1(``!@2```7$@``%A(``!42```4$@``$Q(``!(2```1$@``$!(
M```\2```.$@``#1(```P2```+$@``"A(```D8````&````!@````8````&``
M``!@````8````&`````]@!`"/6OP`(`,O_@Y:ZL0?`D#IGP+6A2!C+_\?6!:
M%$Z`!"!@````8````&````!@````8````&````!@````E"'_\'P(`J:0`0`4
MD\$`"$*?``5_R`*F/]X``3O>:7!+_[^Q@`$`%'P(`Z:#P0`(."$`$$Z``"`0
M`D%4$`!+@!``3I`0`$]0``(``5]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@`````!``6?@0`%H($`!:$!``6A@0`%H@$`!8V!``6>@0`%GP$`!7
MJ!``6-@0`%B`$`!8A!``6=P0`%>P$`!9Y!``6-@0`%G($`!9T!``6-A9@```
M``````````!!S____X```"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,
M;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0````
M`%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````
M4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4`
M``!005)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```%-94U1%
M30``)7,E<R5S)7,`````<&%R+0````!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U
M+25U)7,`````05)'5@`````8````<&5R;``````P````)7,Z(&5X96-U=&EO
M;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@+2!A8F]R=&EN9R!W:71H("5I+@H````M90``+2T``%5315(`````55-%
M4DY!344`````5$5-4$1)4@!435``0SI<5$5-4``O=&UP`````$Q$7TQ)0E)!
M4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?
M4$%42````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H
M:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE
M('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A
M<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI
M<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R
M92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W
M<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES
M"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA
M="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I
M97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I
M=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H
M92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N
M"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U
M<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R
M92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@
M("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@
M,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@
M("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@
M("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@
M($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II
M9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?
M,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H
M,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!
M4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@
M("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE
M(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@
M(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN
M9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T
M(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68[
M"B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E
M96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E
M96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@
M;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@
M("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D
M;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P
M-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F
M:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@
M("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@
M)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@
M("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@
M("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@
M*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@
M)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!]
M(&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L
M(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP
M9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@
M(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I
M86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A3
M3&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE
M="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@
M("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G
M<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@
M('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H
M97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I
M;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ
M92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM[
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO
M=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@
M+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M
M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I
M;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@
M<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@
M("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M
M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S
M92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@
M;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T
M:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.
M0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@
M("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@
M("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D
M7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2![
M"B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@
M("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I
M('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@
M("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@
M;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]
M("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD[
M"@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@
M("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@
M97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM
M<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I
M(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A
M;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS
M,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@
M("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@
M("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@
M("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@
M("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@
M(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D
M+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I
M;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@
M0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO
M9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@
M("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@
M("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@
M("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@
M("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L
M;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET
M92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@
M("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@
M("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T
M('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@
M("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@
M("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S
M('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY
M+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]2
M87<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N
M9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*
M("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN
M(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C
M($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@
M("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R
M(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)
M3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H
M("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@
M)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@
M("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@
M("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@
M("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@
M("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R
M(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@
M8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)
M3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@
M("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@
M875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO
M"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO
M861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R
M:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*
M("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U
M="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@
M("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$
M:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O
M=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B
M*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A
M8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@
M("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^
M<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO
M9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC
M(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*
M("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX
M7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD
M('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!
M4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD
M.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I
M92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@
M("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL
M:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@
M("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T
M7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@
M("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@
M("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C
M('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL
M('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E
M871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE
M<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER
M92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER
M92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V
M87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V
M>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L
M.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3
M<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG
M.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z
M.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*
M("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@
M5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@
M("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@
M("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@
M("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R
M<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@
M:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S
M971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?
M=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H
M(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@
M0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@
M("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@
M(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@
M("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E
M<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD
M:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@
M("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@
M("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@
M("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@
M("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R
M;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@
M("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L
M("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F
M:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE
M("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M"B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL
M96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D[
M"B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L
M:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@
M7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@
M("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]
M("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]
M"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@
M("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S
M+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@
M("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*
M("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@
M("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T
M=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@
M("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@
M("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE
M=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?
M7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@
M("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A
M8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O
M9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?
M"@```'!A<BYP;````1L#.P```!`````!__]?Z````"@````0``````%Z4@`$
M?$$!&PP!`````!`````8__]?N````"0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/____\`````_____P``````````$`'!3!`!OO`0`;[P````
M`0````$````!```"L@````$```,!````#!``%<`````-$`!6<&___O40``&H
M````!1``"E`````&$``#``````H```7V````"P```!`````5``````````,0
M`<```````@```\P````4````!P```!<0`!'T<````!`!O_0````'$``1T```
M``@```/P````"0````QO___^$``1,&____\````";___\!``$$8`````````
M````````````````````````````````````````````````````````````
M$`&_$```````````$`!4\!``5/00`%3X$`!4_!``50`0`%4$$`!5"!``50P0
M`%40$`!5%!``51@0`%4<$`!5(!``5200`%4H$`!5+!``53`0`%4T$`!5.!``
M53P0`%5`$`!51!``54@0`%5,$`!54!``5500`%58$`!57!``56`0`%5D$`!5
M:!``56P0`%5P$`!5=!``57@0`%5\$`!5@!``5800`%6($`!5C!``59`0`%64
M$`!5F!``59P0`%6@$`!5I!``5:@0`%6L$`!5L!``5;00`%6X$`!5O!``5<`0
M`%7$$`!5R!``5<P0`%70$`!5U!``5=@0`%7<$`!5X!``5>00`%7H$`!5[!``
M5?`0`%7T$`!5^!``5?P0`%8`$`!6!!``5@@0`%8,$`!6$!``5A00`%88$`!6
M'!``5B`0`%8D$`!6*!``5BP0`%8P````````````````_____Q``MB```%OI
M1T-#.B`H56)U;G1U+TQI;F%R;R`T+C4N,BTQ=6)U;G1U,BD@-"XU+C(`00``
M`!-G;G4``0````L$`0@!#`(`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR
M96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9V]T,@`N9'EN86UI
M8P`N9V]T`"YD871A`"YS9&%T80`N8G-S`"YC;VUM96YT`"YG;G4N871T<FEB
M=71E<P``````````````````````````````````````````````````````
M````"P````$````"$``!5````50````-```````````````!`````````!,`
M```'`````A```60```%D````(```````````````!``````````A````!P``
M``(0``&$```!A````"0```````````````0`````````-&____8````"$``!
MJ````:@```%8````!0`````````$````!````#X````+`````A```P````,`
M```'4`````8````!````!````!````!&`````P````(0``I0```*4```!?8`
M``````````````$`````````3F____\````"$``01@``$$8```#J````!0``
M```````"`````@```%MO___^`````A``$3```!$P````H`````8````"````
M!`````````!J````!`````(0`!'0```1T````"0````%``````````0````,
M````=`````0````"$``1]```$?0```/,````!0```!<````$````#````'X`
M```!````!A``%<```!7`````3```````````````!`````````"$`````0``
M``80`!80```6$```0&```````````````!``````````B@````$````&$`!6
M<```5G`````X```````````````$`````````)`````!`````A``5J@``%:H
M``!?@```````````````"`````````"8`````0````(0`+8H``"V*````!0`
M``````````````0`````````I@````$````"$`"V/```MCP````L````````
M```````$`````````+`````!`````Q`!OO```+[P````"```````````````
M!`````````"W`````0````,0`;[X``"^^`````@```````````````0`````
M````O@````$````#$`&_````OP`````$```````````````$`````````,,`
M```!`````Q`!OP0``+\$````#````````````````0````````#)````!@``
M``,0`;\0``"_$````.`````&``````````0````(````T@````$````#$`&_
M\```O_`````0```````````````$````!````'D````!`````Q`!P````,``
M```!1```````````````!`````````#7`````0````,0`<%$``#!1````!``
M``````````````0`````````W0````$````#$`'!5```P50````(````````
M```````$`````````.0````(`````Q`!P6```,%<```00```````````````
M$`````````#I`````0```#````````#!7````"H```````````````$````!
M````\F____4`````````````P88````4```````````````!``````````$`
C```#`````````````,&:```!`@```````````````0``````
